require 'simplecov'
require 'coveralls'

SimpleCov.formatter = SimpleCov::Formatter::MultiFormatter[
  SimpleCov::Formatter::HTMLFormatter,
  Coveralls::SimpleCov::Formatter
]
SimpleCov.start

require 'ticketing_hub'
require 'rspec'
require 'webmock/rspec'

WebMock.disable_net_connect! allow: 'coveralls.io'

RSpec.configure do |config|
  config.expect_with :rspec do |c|
    c.syntax = :expect
  end
end

def a_delete(url)
  a_request(:delete, ticketinghub_url(url))
end

def a_get(url)
  a_request(:get, ticketinghub_url(url))
end

def a_patch(url)
  a_request(:patch, ticketinghub_url(url))
end

def a_post(url)
  a_request(:post, ticketinghub_url(url))
end

def a_put(url)
  a_request(:put, ticketinghub_url(url))
end

def stub_delete(url)
  stub_request(:delete, ticketinghub_url(url))
end

def stub_get(url)
  stub_request(:get, ticketinghub_url(url))
end

def stub_head(url)
  stub_request(:head, ticketinghub_url(url))
end

def stub_patch(url)
  stub_request(:patch, ticketinghub_url(url))
end

def stub_post(url)
  stub_request(:post, ticketinghub_url(url))
end

def stub_put(url)
  stub_request(:put, ticketinghub_url(url))
end

def fixture_path
  File.expand_path("../fixtures", __FILE__)
end

def fixture(file)
  File.new(fixture_path + '/' + file)
end

def json_response(file)
  { body: fixture(file),
    headers: { content_type: 'application/json; charset=utf-8' } }
end

def ticketinghub_url(url)
  if url =~ /^http/
    url
  elsif @client && @client.authenticated?
    "https://#{@client.token}:#{@client.secret}@api.ticketinghub.com#{url}"
  else
    "https://api.ticketinghub.com#{url}"
  end
end